Skip to contents

This function consolidates the retrieval and caching and transformation of scverse-curated Zarr archives and 10x-curated Xenium archives.

Usage

SD.data_load(id, target = tempfile(), src)

Arguments

id

character string; dataset identifier

target

character(1), defaults to tempfile(); use a different value if you wish to retain the unzipped .zarr store persistently.

src

The name of the source, i.e. query bucket.

biocOSN

Bioc's Open Storage Network (NSF) OSN bucket (spatialdata v0.3.0, zarr v2)

sandbox

scverse's spatialdata-sandbox bucket at EMBL.

Value

an instance of SpatialData, or throws an error if the dataset identifier (id)does not uniquely match the name of any resource, see SD.data_list for the list of datasets.

Details

Examples

Sys.setenv(AWS_REGION = "us-east-1")

# load using `SD.data_load`
ld <- SD.data_load("ColorectalCarcinomaMIBITOF")
#> checking scverse spatialdata-sandbox bucket...
#> caching mibitof_spatialdata_0.7.1.zip
#> 
ld
#> class: SpatialData
#> - images(3):
#>   - point16_image (3,1024,1024)
#>   - point23_image (3,1024,1024)
#>   - point8_image (3,1024,1024)
#> - labels(3):
#>   - point16_labels (1024,1024)
#>   - point23_labels (1024,1024)
#>   - point8_labels (1024,1024)
#> - points(0):
#> - shapes(0):
#> - tables(1):
#>   - table (36,3309) [point8_labels,point16_labels,point23_labels]
#> coordinate systems(3):
#> - point16(2): point16_image point16_labels
#> - point23(2): point23_image point23_labels
#> - point8(2): point8_image point8_labels

# load data from biocOSN source (Zarr v2)
ld <- SD.data_load("ColorectalCarcinomaMIBITOF", src = "biocOSN")
#> checking Bioconductor OSN bucket...
#> caching mibitof.zip
#>